package Bundle::Locale::CLDR::Northernafrica;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Northernafrica

=head1 CONTENTS

Locale::CLDR::Locales::Ar 0.34.1
Locale::CLDR::Locales::Es 0.34.1
Locale::CLDR::Locales::Fr 0.34.1
Locale::CLDR::Locales::Kab 0.34.1
Locale::CLDR::Locales::Shi 0.34.1
Locale::CLDR::Locales::Tzm 0.34.1
Locale::CLDR::Locales::Zgh 0.34.1
Locale::CLDR::Locales::Ar::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Es::Any 0.34.1
Locale::CLDR::Locales::Fr::Any 0.34.1
Locale::CLDR::Locales::Kab::Any 0.34.1
Locale::CLDR::Locales::Tzm::Any 0.34.1
Locale::CLDR::Locales::Zgh::Any 0.34.1
Locale::CLDR::Locales::Shi::Latn 0.34.1
Locale::CLDR::Locales::Shi::Tfng 0.34.1
Locale::CLDR::Locales::Ar::Any::Dz 0.34.1
Locale::CLDR::Locales::Ar::Any::Eg 0.34.1
Locale::CLDR::Locales::Ar::Any::Eh 0.34.1
Locale::CLDR::Locales::Ar::Any::Ly 0.34.1
Locale::CLDR::Locales::Ar::Any::Ma 0.34.1
Locale::CLDR::Locales::Ar::Any::Sd 0.34.1
Locale::CLDR::Locales::Ar::Any::Tn 0.34.1
Locale::CLDR::Locales::En::Any::Sd 0.34.1
Locale::CLDR::Locales::Es::Any::Ea 0.34.1
Locale::CLDR::Locales::Es::Any::Ic 0.34.1
Locale::CLDR::Locales::Fr::Any::Dz 0.34.1
Locale::CLDR::Locales::Fr::Any::Ma 0.34.1
Locale::CLDR::Locales::Fr::Any::Tn 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::Kab::Any::Dz 0.34.1
Locale::CLDR::Locales::Tzm::Any::Ma 0.34.1
Locale::CLDR::Locales::Zgh::Any::Ma 0.34.1
Locale::CLDR::Locales::Shi::Latn::Ma 0.34.1
Locale::CLDR::Locales::Shi::Tfng::Ma 0.34.1

=cut

1;

